@@ -26,6 +26,10 @@ class BaseWalker(TargetableAgent):
 
 
 class WaitingUniformWalker(BaseWalker):
+    """
+    The `WaitingUniformWalker` is a uniform walker with a fixed transition probability. Upon reaching a target, if the
+
+    """
     def __init__(self, x_init: float, y_init: float, velocity: float = 1.0, wait_transition_probability: float = 0.4):
         super(WaitingUniformWalker, self).__init__(x_init=x_init, y_init=y_init, velocity=velocity)
         self.wait_transition_probability = wait_transition_probability
@@ -143,3 +147,35 @@ class RapidHomesickLevyWalker(BaseWalker):
                     self.move()
                 else:
                     self.set_absolute_target(self.home_x, self.home_y)
+
+
+class VariableVelocityWalker(BaseWalker):
+    """
+    Variable velocity walkers have a velocity distributed based on a probability distribution, `velocity_distribution`.
+    In general, velocities cannot be negative. There are two behaviours, conditioned by the `reflect` parameter:
+
+    * reflection (`reflect = True`): if the random value from the distribution is negative, the absolute value is taken,
+    * capping (`reflect = True`): if the random value from the distribution is negative, 0 is used.
+    """
+    def __init__(self,
+                 x_init: float,
+                 y_init: float,
+                 velocity: float = 1.0,
+                 velocity_distribution: stats.rv_continuous = stats.norm,
+                 reflect = False,
+                 **kwargs):
+        super(VariableVelocityWalker, self).__init__(x_init=x_init, y_init=y_init, velocity=velocity)
+        self.velocity_distribution, self.kwargs = velocity_distribution, kwargs
+        self.reflect = reflect
+
+
+    def update(self):
+        _velocity = self.velocity_distribution(**self.kwargs).rvs()
+        if _velocity >= 0:
+            self.velocity = _velocity
+        else:
+            if self.reflect:
+                self.velocity = -1 * _velocity
+            else:
+                self.velocity = 0
+        super(VariableVelocityWalker, self).update()
